"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateTagsFilters = void 0;
var Utils_1 = require("@devesharp/react-utils/lib/Utils");
var format_1 = __importDefault(require("date-fns/format"));
var pt_BR_1 = __importDefault(require("date-fns/locale/pt-BR"));
var flattenDeep_1 = __importDefault(require("lodash/flattenDeep"));
var isEqual_1 = __importDefault(require("lodash/isEqual"));
var TagsFilters_interface_1 = require("./TagsFilters.interface");
function generateTagsFilters(filters, filtersSchema) {
    var tags = Object.entries(filters || {})
        .filter(function (_a) {
        var key = _a[0];
        return filtersSchema[key];
    })
        .filter(function (_a) {
        var key = _a[0], value = _a[1];
        return (!Utils_1.IsEmpty(value) && !isEqual_1.default(value, filtersSchema[key].default)) || value === 0 || value === '0';
    })
        .filter(function (_a) {
        var key = _a[0], value = _a[1];
        return filtersSchema[key].ignore
            ? filtersSchema[key].ignore.map(function (e) { return e.toString(); }).indexOf(filters[key].toString())
            : true;
    })
        .map(function (_a) {
        var _b, _c, _d, _e, _f, _g, _h;
        var key = _a[0], value = _a[1];
        var filtersSchemaKey = (_b = filtersSchema[key]) !== null && _b !== void 0 ? _b : {};
        var modifierValue = value;
        var calendarDate;
        switch (filtersSchemaKey.type) {
            case TagsFilters_interface_1.ETagFilterType.Select:
                return {
                    key: key,
                    type: filtersSchemaKey.type,
                    default: filtersSchemaKey.default || '',
                    value: filtersSchemaKey.values[filters[key]],
                };
            case TagsFilters_interface_1.ETagFilterType.Location:
                return value.split('_').map(function (i) {
                    var location = i.split(',');
                    var locationString;
                    if (location.length === 3) {
                        var estate = location[0], city = location[1], neighborhood = location[2];
                        locationString = neighborhood + " - " + city + ", " + estate;
                    }
                    else if (location.length === 2) {
                        var estate = location[0], city = location[1];
                        locationString = city + ", " + estate;
                    }
                    else {
                        return null;
                    }
                    return {
                        key: key,
                        type: 'location',
                        parentValue: filters[key],
                        value: locationString,
                        locationValue: i,
                        values: value,
                    };
                });
            case TagsFilters_interface_1.ETagFilterType.CheckBox:
                return value
                    .map(function (i) {
                    return filtersSchemaKey.values[i]
                        ? {
                            key: key,
                            type: 'checkbox',
                            default: false,
                            checkboxValue: i,
                            parentValue: filters[key],
                            value: filtersSchemaKey.values[i],
                            values: value,
                        }
                        : null;
                })
                    .filter(function (i) { return !Utils_1.IsEmpty(i); });
            case TagsFilters_interface_1.ETagFilterType.CheckBoxKey:
                return Object.entries(value)
                    .filter(function (_a) {
                    var k = _a[0], v = _a[1];
                    return v;
                })
                    .map(function (_a) {
                    var k = _a[0], v = _a[1];
                    return k;
                })
                    .map(function (i) {
                    return filtersSchemaKey.values[i]
                        ? {
                            key: key,
                            type: TagsFilters_interface_1.ETagFilterType.CheckBoxKey,
                            default: false,
                            checkboxValue: i,
                            parentValue: filters[key],
                            value: filtersSchemaKey.values[i],
                            values: value,
                        }
                        : null;
                })
                    .filter(function (i) { return !Utils_1.IsEmpty(i); });
            case TagsFilters_interface_1.ETagFilterType.Date:
                return {
                    key: key,
                    type: 'input',
                    prefix: (_c = filtersSchemaKey.prefix) !== null && _c !== void 0 ? _c : '',
                    suffix: (_d = filtersSchemaKey.suffix) !== null && _d !== void 0 ? _d : '',
                    value: format_1.default(value, filtersSchemaKey.format || 'dd/MM/yyyy', { locale: pt_BR_1.default }),
                    default: (_e = filtersSchemaKey.default) !== null && _e !== void 0 ? _e : '',
                };
            case TagsFilters_interface_1.ETagFilterType.Input:
            case TagsFilters_interface_1.ETagFilterType.InputNumber:
            case TagsFilters_interface_1.ETagFilterType.InputPrice:
            default:
                if (filtersSchemaKey.type === 'price') {
                    var decimals = filtersSchemaKey.decimals || 2;
                    modifierValue = Utils_1.NumberFormat(Number(modifierValue), decimals).toString();
                }
                if (filtersSchemaKey.type === 'number') {
                    var decimals = filtersSchemaKey.decimals || 0;
                    modifierValue = Utils_1.NumberFormat(Number(modifierValue), decimals).toString();
                }
                return {
                    key: key,
                    type: 'input',
                    prefix: (_f = filtersSchemaKey.prefix) !== null && _f !== void 0 ? _f : '',
                    suffix: (_g = filtersSchemaKey.suffix) !== null && _g !== void 0 ? _g : '',
                    value: modifierValue,
                    default: (_h = filtersSchemaKey.default) !== null && _h !== void 0 ? _h : '',
                };
        }
    })
        .filter(function (i) { return !Utils_1.IsEmpty(i); })
        .map(function (tag) { return tag; });
    return flattenDeep_1.default(tags);
}
exports.generateTagsFilters = generateTagsFilters;
//# sourceMappingURL=TagsFilters.utils.js.map